pub struct MockAuthRequestsApi {
AuthRequestsApi_expectations: MockAuthRequestsApi_AuthRequestsApi,
}Fields
AuthRequestsApi_expectations: MockAuthRequestsApi_AuthRequestsApiImplementations
Sourceimpl MockAuthRequestsApi
impl MockAuthRequestsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockAuthRequestsApi
impl MockAuthRequestsApi
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_get_pending_auth_requests(&mut self) -> &mut Expectation
pub fn expect_get_pending_auth_requests(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_pending_auth_requests method
Sourcepub fn expect_get_response(&mut self) -> &mut Expectation
pub fn expect_get_response(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_response method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_post_admin_request(&mut self) -> &mut Expectation
pub fn expect_post_admin_request(&mut self) -> &mut Expectation
Create an Expectation for mocking the post_admin_request method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method